require "test_helper"

describe PaperCup::Response do

  describe "when the response is not JSON" do
    it "must set the response as it came " do
      assert_nothing_raised { PaperCup::Response.new(Mock.html) }
    end

    it "must set the status code response properly" do
      r = PaperCup::Response.new(Mock.html)
      assert_equal 404, r.status
    end

  end

  describe "when the response is a JSON" do
    describe "and an array" do
      it "must be an array of RecursiveOpenStruct" do
        r = PaperCup::Response.new(Mock.json_array)
        assert_equal 1, r.body.map(&:class).uniq.count, "There must be only one kind of objects"
        assert_equal RecursiveOpenStruct, r.body.map(&:class).uniq.first, "The class of the elements must be RecursiveOpenStruct"
      end

      it "must set the response properly" do
        r = PaperCup::Response.new(Mock.json_array)
        assert_equal JSON.parse(Mock.json_array[0..-4]).first["framework"], r.body.first.framework
      end

      it "must set the status code response properly" do
        r = PaperCup::Response.new(Mock.json_array)
        assert_equal 200, r.status
      end
    end
    describe "and not an array" do
      it "must be a RecursiveOpenStruct object" do
        r = PaperCup::Response.new(Mock.json)
        assert_equal RecursiveOpenStruct, r.body.class, "The class of the elements must be RecursiveOpenStruct"
      end

      it "must set the response properly" do
        r = PaperCup::Response.new(Mock.json)
        assert_equal JSON.parse(Mock.json[0..-4])["framework"], r.body.framework
      end

      it "must set the status code response properly" do
        r = PaperCup::Response.new(Mock.json)
        assert_equal 200, r.status
      end
    end
  end
end
